domkm.silk


?clj/s

(? ptrn & [default-params])
source

arriveclj/s

(arrive rtes x)
(arrive rtes x handler)
source

boolclj/s

(bool k)
source

catclj/s

(cat & ptrns)
source

create-defaultclj/s

(create-default ptrn)
(create-default ptrn v)
source

decodeclj/s

(decode s)
source

decode-pathclj/s

(decode-path s)

Takes a path string. Returns a vector of decoded path segments.

Takes a path string.
Returns a vector of decoded path segments.
sourceraw docstring

decode-queryclj/s

(decode-query s)

Takes a query string. Returns a map of decoded query pairs.

Takes a query string.
Returns a map of decoded query pairs.
sourceraw docstring

departclj/s

(depart rtes nm)
(depart rtes nm params)
(depart rtes nm params handler)
source

encodeclj/s

(encode s)
source

encode-pathclj/s

(encode-path path)

Takes a path seqable. Returns a string of path segments encoded, joined with /, and prepended with /.

Takes a path seqable.
Returns a string of path segments encoded, joined with `/`, and prepended with `/`.
sourceraw docstring

encode-queryclj/s

(encode-query query)

Takes a query map. Returns a string of query pairs encoded and joined.

Takes a query map.
Returns a string of query pairs encoded and joined.
sourceraw docstring

intclj/s

(int k)
source

matchclj/s

(match ptrn x)
source

match-valid?clj/s

(match-valid? ptrn x)
source

match-validatorclj/s

(match-validator ptrn)
source

Patternclj/sprotocol

-create-defaultclj/s

(-create-default this v)

-matchclj/s

(-match this that)

-match-validatorclj/s

(-match-validator this)

-unmatchclj/s

(-unmatch this params)

-unmatch-validatorsclj/s

(-unmatch-validators this)
source

pattern?clj/s

(pattern? x)
source

regexclj/s≠

clj
(regex k re)
(regex
  k
  re
  {:keys [deserialize serialize validate]
   :or {deserialize identity
        serialize (fn* [p1__2193#]
                       (if (vector? p1__2193#) (nth p1__2193# 0) p1__2193#))
        validate (fn* [p1__2194#]
                      (when-let
                        [s (if (vector? p1__2194#) (first p1__2194#) p1__2194#)]
                        (and (string? s) (re-find re s))))}})
cljs
(regex k re)
(regex
  k
  re
  {:keys [deserialize serialize validate]
   :or {deserialize identity
        serialize (fn* [p1__3432#]
                       (if (vector? p1__3432#) (nth p1__3432# 0) p1__3432#))
        validate (fn* [p1__3433#]
                      (when-let
                        [s (if (vector? p1__3433#) (first p1__3433#) p1__3433#)]
                        (and (string? s) (re-find re s))))}})
source

routeclj/s

(route x)
source

route?clj/s

(route? x)
source

routesclj/s

(routes rtes)
source

routes?clj/s

(routes? x)
source

unmatchclj/s

(unmatch ptrn params)
source

unmatch-valid?clj/s

(unmatch-valid? ptrn params)
source

unmatch-validatorsclj/s

(unmatch-validators ptrn)
source

urlclj/s

(url x)
source

url-patternclj/s

(url-pattern x)
source

url?clj/s

(url? x)
source

uuidclj/s

(uuid k)
source

cljdoc builds & hosts documentation for Clojure/Script libraries