(decode-path s)Takes a path string. Returns a vector of decoded path segments.
Takes a path string. Returns a vector of decoded path segments.
(decode-query s)Takes a query string. Returns a map of decoded query pairs.
Takes a query string. Returns a map of decoded query pairs.
(encode-path path)Takes a path seqable.
Returns a string of path segments encoded, joined with /, and prepended with /.
Takes a path seqable. Returns a string of path segments encoded, joined with `/`, and prepended with `/`.
(encode-query query)Takes a query map. Returns a string of query pairs encoded and joined.
Takes a query map. Returns a string of query pairs encoded and joined.
(-create-default this v)(-match this that)(-match-validator this)(-unmatch this params)(-unmatch-validators this)(regex k re)(regex
k
re
{:keys [deserialize serialize validate]
:or {deserialize identity
serialize (fn* [p1__2193#]
(if (vector? p1__2193#) (nth p1__2193# 0) p1__2193#))
validate (fn* [p1__2194#]
(when-let
[s (if (vector? p1__2194#) (first p1__2194#) p1__2194#)]
(and (string? s) (re-find re s))))}})(regex k re)(regex
k
re
{:keys [deserialize serialize validate]
:or {deserialize identity
serialize (fn* [p1__3432#]
(if (vector? p1__3432#) (nth p1__3432# 0) p1__3432#))
validate (fn* [p1__3433#]
(when-let
[s (if (vector? p1__3433#) (first p1__3433#) p1__3433#)]
(and (string? s) (re-find re s))))}})cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |