(request-map->URL {:keys [scheme server-name server-port uri query-string]
:as req})(ring-handler routes)(ring-handler routes get-handler)Takes a routes data structure or instance of domkm.silk/Routes and a get-handler function.
get-handler should take a route name and return a handler function for that route.
Returns a Ring handler function that:
Takes a routes data structure or instance of `domkm.silk/Routes` and a `get-handler` function. `get-handler` should take a route name and return a handler function for that route. Returns a Ring handler function that: * takes Ring request map * converts the request map to a URL * associates the request map into the URL * matches routes against the new URL * when a match is found, associates params into request and passes that to a route handler function
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |